@@ -1,6 +1,7 @@
 use crate::utils::languages::{languages as lang_list, Language};
 use std::str::from_utf8;
 
+/// export versions in all installed languages.
 pub fn languages() {
     let languages = lang_list();
 
@@ -9,16 +10,24 @@ pub fn languages() {
     }
 }
 
+/// export target language version.
 pub fn selected_languages(target: &str) {
     let languages = lang_list();
+    let mut flag = false;
 
     for lang in languages.iter() {
         if lang.search(target) {
             export_version(&lang);
+            flag = true;
         }
     }
+
+    if !flag {
+        println!("🔸 {} is not found", target)
+    }
 }
 
+/// export version.
 fn export_version(lang: &Language) {
     let result = lang.run();
 
@@ -28,5 +37,7 @@ fn export_version(lang: &Language) {
             println!("🔹 {}", lang.command);
             println!("\t{}", version.replace("\n", "\n\t"));
         }
+    } else {
+        println!("🔸 {} is not found\n", lang.command);
     }
 }
