@@ -60,8 +60,13 @@ impl Parse {
                     Tracking::Delete { id } => {
                         tracker.delete(id)?;
                     }
-                    Tracking::History { id } => {
-                        tracker.history(id)?;
+                    Tracking::History {
+                        id,
+                        oneline,
+                        all,
+                        graph,
+                    } => {
+                        tracker.history(id, *oneline, *all, *graph)?;
                     }
                     Tracking::List => {
                         tracker.list()?;
